@@ -492,6 +492,14 @@ class Framework_Washtml extends PHPUnit\Framework\TestCase
                 '<html><svg><animate attributeName="href " values="javascript:alert(\'XSS\')" href="#link" /></animate></svg></html>',
                 '<svg><!-- animate blocked --></svg>',
             ],
+            [
+                '<html><svg><defs><filter><feImage href="http://external.site"/></filter></defs></html>',
+                '<svg><defs><filter><feImage x-washed="href"></feImage></filter></defs></svg>',
+            ],
+            [
+                '<html><svg><defs><filter><feImage xlink:href="http://external.site"/></filter></defs></html>',
+                '<svg><defs><filter><feImage x-washed="xlink:href"></feImage></filter></defs></svg>',
+            ],
         ];
     }
 
